@@ -41,7 +41,29 @@ class _DataFrame:
 
         if response.json()["code"] is 200:
             return True
+        if response.status_code is 413:
+            raise Exception("Size of the data exceeds the maximum of 5MB, please use the append method instead.")
         else:
             raise Exception(response.json()["message"])
-        
 
+
+    def Append(self, dataframe):
+        if not Auth.tokenValid():
+            Auth.refreshToken()
+        
+        jsonObject = json.loads(dataframe.to_json(orient='index'))
+
+        for id in jsonObject:
+            response = requests.post(settings.baseURL + 'api/metric/' + self.app_id + '/' + self.collection_id, json={
+                "id": id,
+                "data": jsonObject[id]
+            }, headers={
+                'Authorization': 'Bearer ' + settings.token
+            })
+
+            if response.json()["code"] is 200:
+                continue
+            else:
+                raise Exception(response.json()["message"])
+
+        return True
